@@ -36,6 +36,8 @@ setLocalTranslate('cl_lib3', sys.modules[__name__])
 class GitError(AddonError):
     """Git Error"""
 
+class NotGitError(GitError):
+    """Данная директория не является Git"""
 
 class Git:
     """
@@ -57,7 +59,7 @@ class Git:
                     _("Repository {path} is not a directory").format(
                         path=rpath))
             if not path.isdir(self._gitDir(rpath)):
-                raise GitError(
+                raise NotGitError(
                     _("Repository {path} is not Git").format(
                         path=rpath))
             return True
@@ -453,7 +455,7 @@ class Git:
         """
         git_port, target = self._parse_url(url)
         if git_port != self.GitProtocol.Unknown:
-            return check_port(target, git_port)
+            return check_port(target, git_port, timeout=20)
         return True
 
     def isNeedUnpack(self, rpath, fns=(".gitignore",
